.. django-dashboards documentation master file, created by
   sphinx-quickstart on Thu Oct 27 14:05:56 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Dashboards
==========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   howto/quickstart.rst
   howto/dashboards.rst
   howto/layout.rst
   howto/permissions.rst
   howto/components/index.rst
   howto/serializers/index.rst
   howto/templates.rst
   howto/menus.rst
   howto/views.rst
   howto/dynamic.rst
   howto/async.rst
   howto/sse.rst
   howto/settings.rst
   howto/demo.rst
